LoginButtons class

Constructors

LoginButtons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

apple({required VoidCallback onPressed, String text = 'Continue with Apple', LoginButtonStyle style = LoginButtonStyle.white, bool isLoading = false}) Widget
google({required VoidCallback onPressed, String text = 'Continue with Google', LoginButtonStyle style = LoginButtonStyle.white, bool isLoading = false}) Widget
linkedin({required VoidCallback onPressed, String text = 'Continue with LinkedIn', LoginButtonStyle style = LoginButtonStyle.white, bool isLoading = false}) Widget